@@ -7,6 +7,7 @@ from .image import Image
 from .thread import async_process
 from .exceptions import EmbedException
 from .configs import get_request_method
+from urllib.parse import urljoin
 
 
 class Embed:
@@ -27,12 +28,12 @@ class Embed:
     def __init__(self, url):
         start_time = time.time()
         self._entered_url = url
-        self.parse_url(url)
+        self.validate_headers()
         self.fetch_content(get_request_method(self.url.get_provider(), self._parser_class.Parser.fetch_method))
         self._timings['total_time'] = time.time() - start_time
 
     def validate_headers(self):
-        response = Request(self.url.get_origin_url()).get_headers()
+        response = Request(self.url.origin_url if self.url is not None else self._entered_url).get_headers()
 
         if response and response.get_content_type() and not response.is_content_type_valid():
             raise EmbedException(
@@ -40,7 +41,10 @@ class Embed:
                 "Content type is not supported" if response.status_code == 200 else response.message
             )
 
-        self.parse_url(response.url)
+        if response:
+            self.parse_url(response.url)
+        else:
+            self.parse_url(self.url.origin_url if self.url is not None else self._entered_url)
 
     def fetch_content(self, method):
         fetch_method = None
@@ -54,7 +58,8 @@ class Embed:
             method = fetch_method
 
         self._last_fetched_url = self.url.get_origin_url()
-        response = getattr(Request(self.url.get_origin_url()), method)()
+        response = getattr(Request(self.url.origin_url), method)()
+        self.parse_url(response.url)
 
         if response and (self._last_fetched_method is None or self._last_fetched_method != 'selenium'):
             self._last_fetched_method = method
@@ -67,7 +72,8 @@ class Embed:
                     raise EmbedException(400, "Invalid url")
 
                 if fetch[1]:
-                    self.parse_url(fetch[1])
+                    self.url.origin_url = urljoin(self.url.origin_url, fetch[1].strip("\'"))
+                    # self.parse_url(fetch[1])
 
                 if fetch[0]:
                     self.fetch_content(fetch[0])
