@@ -1,4 +1,4 @@
-meta = """<meta(?=(?:[^\>]+)?(?:^|\s)\\b(?:name|property)\\b(?:\s*)=(?:\s*)(?:\"|\')?(?:\s*)(og:title|twitter:title|og:description|twitter:description|description|twitter:player|twitter:player:width|twitter:player:height|author|twitter:author|article:author|og:image|twitter:image|twitter:image:src|og:type|robots)(?:\"|\')?(?:[ \/\>]))(?:(?:[^\>]+)?(?:^|\s)(?:content|value|ng-attr-content)\\b(?:\s*)=(?:\s*)(?:(?=\")"([^\"]+)"|(?:(?=\')'([^\']+)'|(?!\'\")([^\s\>]+))))(?:[^\>]+)?>"""
+meta = """<meta(?=(?:[^\>]+)?(?:^|\s)\\b(?:name|property|itemprop)\\b(?:\s*)=(?:\s*)(?:\"|\')?(?:\s*)(og:title|twitter:title|og:description|twitter:description|description|twitter:player|twitter:player:width|twitter:player:height|author|twitter:author|article:author|og:image|twitter:image|twitter:image:src|og:type|robots|duration)(?:\"|\')?(?:[ \/\>]))(?:(?:[^\>]+)?(?:^|\s)(?:content|value|ng-attr-content)\\b(?:\s*)=(?:\s*)(?:(?=\")"([^\"]+)"|(?:(?=\')'([^\']+)'|(?!\'\")([^\s\>]+))))(?:[^\>]+)?>"""
 title = "<title[^>]*>([^>]+)<\/title>"
 body = "<body([\S\D]+)(<\/body ?>)?"
 body_image_with_extension = """<(?:amp-)?img(?=[^\>]+(?:jpe?g|gif|png|tiff|bmp))(?=(?:.+?)src(?:set)?(?=.+)\s*\=(?:(?=\')'([^\'\>]+)'|(?:(?=\")"([^\"\>]+)"|(?!\'\")([^\s\>]+))))(?:[^\>]+)?>"""
@@ -6,3 +6,6 @@ body_image_without_extension = """<(?:amp-)?img(?![^\>]+(?:jpe?g|gif|png|tiff|bm
 url = "(((?:http|ftp)s?):\/\/(?:www)?\.?(([^\.]+)\.([^\/\.]+)\.?([^\/\.]+)?\.?([^\/\.]+)?\.?([^\/\.]+)?))(?:.+)?"
 meta_redirect_url = """<meta\s+http(?:s)?-equiv[^\>](?:\s*.*)(?:.+?)url\s*=\s*(?:([^\"\>]+)")(?:[^\>]+)?>"""
 js_redirect_url = """(?:(?:location\.(?:href|assign|replace)|window\.location(?:\.href)?)\s*(?:=|\()+\s*(?:\"|\')([^(\"|\')]+)(?:\"|\'))"""
+youtube_id = "^(?:https?:\/\/)?(?:www\.)?(?:m\.)?(?:youtube\.com\/watch\?v=([a-zA-Z0-9_-]*)|youtu\.be\/([a-zA-Z0-9_-]*)|(?:.*)youtube\.com\/embed\/([a-zA-Z0-9_-]*))"
+vimeo_id = "https?:\/\/(?:www\.)?vimeo\.com\/([0-9]+)"
+vimeo_duration = '"duration":{"raw":([\d]+)'
